@@ -5,10 +5,9 @@ require Exporter;
 use vars qw($config $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Config::EXPORT  = qw(loadConfig saveConfig $config);
 @ISA                           = qw(Exporter);
-$MySQL::Admin::Config::VERSION = '0.44';
-$DefaultClass                  = 'MySQL::Admin::Config'
-    unless defined $MySQL::Admin::Config::DefaultClass;
-$defaultconfig = '%CONFIG%';
+$MySQL::Admin::Config::VERSION = '0.47';
+$DefaultClass                  = 'MySQL::Admin::Config' unless defined $MySQL::Admin::Config::DefaultClass;
+$defaultconfig                 = '%CONFIG%';
 
 =head1 NAME
 
@@ -28,8 +27,9 @@ loadConfig() saveConfig() $config
 
 =cut
 
-sub new {
-    my ( $class, @initializer ) = @_;
+sub new
+{
+    my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
@@ -39,20 +39,20 @@ sub new {
 
 =cut
 
-sub loadConfig {
-    my ( $self, @p ) = getSelf(@_);
-    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
-    if ( -e $do ) {
-        do $do;
-    }
+sub loadConfig
+{
+    my ($self, @p) = getSelf(@_);
+    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
+    if (-e $do) {do $do;}
 }
 
 =head2 saveConfig()
 
 =cut
 
-sub saveConfig {
-    my ( $self, @p ) = getSelf(@_);
+sub saveConfig
+{
+    my ($self, @p) = getSelf(@_);
     my $saveAs = defined $p[0] ? $p[0] : $defaultconfig;
     $config = defined $p[1] ? $p[1] : $config;
     my $var = defined $p[2] ? $p[2] : 'config';
@@ -65,23 +65,15 @@ sub saveConfig {
     my $rsas = $saveAs =~ /^(\S+)$/ ? $1 : 0;
 
     if ($rsas) {
-        open $fh, ">$rsas.bak"
-            or warn
-            "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: "
-            . caller()
-            . $/;
+        open $fh, ">$rsas.bak" or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: " . caller() . $/;
         flock $fh, 2;
         seek $fh, 0, 0;
         truncate $fh, 0;
         print $fh $content;
         close $fh;
     }
-    if ( -e "$rsas.bak" ) {
-        rename "$rsas.bak", $rsas
-            or warn
-            "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: "
-            . caller()
-            . $/;
+    if (-e "$rsas.bak") {
+        rename "$rsas.bak", $rsas or warn "$/MySQL::Admin::Config::saveConfig$/ $! $/ File: $rsas $/Caller: " . caller() . $/;
         do $rsas;
     }
 }
@@ -94,15 +86,12 @@ see L<HTML::Menu::TreeView>
 
 =cut
 
-sub getSelf {
-    return @_
-        if defined( $_[0] )
-            && ( !ref( $_[0] ) )
-            && ( $_[0] eq 'MySQL::Admin::Config' );
-    return ( defined( $_[0] )
-                 && ( ref( $_[0] ) eq 'MySQL::Admin::Config'
-                      || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Config' ) )
-    ) ? @_ : ( $MySQL::Admin::Config::DefaultClass->new, @_ );
+sub getSelf
+{
+    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Config');
+    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Config' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Config')))
+      ? @_
+      : ($MySQL::Admin::Config::DefaultClass->new, @_);
 }
 
 =head2 see Also
